.. _mod-dr:

DR
---

.. automodule:: paradime.dr
   :members:

.. _mod-relations:

Relations
---------

.. automodule:: paradime.relations
   :members:

.. _mod-reldata:

Relation Data
-------------

.. automodule:: paradime.relationdata
   :members:

.. _mod-transforms:

Transforms
----------

.. automodule:: paradime.transforms
   :members:

.. _mod-loss:

Loss
----

.. automodule:: paradime.loss
   :members:

.. _mod-routines:

Routines
--------

.. automodule:: paradime.routines
   :members:

Utils
-----

.. automodule:: paradime.utils
   :members:

Convert
~~~~~~~

.. automodule:: paradime.utils.convert
   :members:

Logging
~~~~~~~

.. automodule:: paradime.utils.logging
   :members:

Plotting
~~~~~~~~

.. automodule:: paradime.utils.plotting
   :members:

Seed
~~~~

.. automodule:: paradime.utils.seed
   :members: